@@ -61,20 +61,30 @@ void PIRCameraForm::enableButtons(
   unsigned int id)
 {
   emit openShutterEnabled(km->hasKey(id, OpenShutter_Key));
+  emit delayedOpenShutterEnabled(km->hasKey(id, DelayedOpenShutter_Key));
 }
 
 
 void PIRCameraForm::on_openShutterButton_pressed()
 {
-  if (ui->remoteFlashCheckBox->isChecked())
+  if ( ui->delayedShutterCheckBox->isEnabled()
+    && ui->delayedShutterCheckBox->isChecked())
   {
-    flash = new PIRFlashLED();
-    flash->strobe();
+    mainWindow->startRepeating(DelayedOpenShutter_Key);
   }
+  else
+  {
+    if (ui->remoteFlashCheckBox->isChecked())
+    {
+      flash = new PIRFlashLED();
+      flash->strobe();
+    }
 
-  mainWindow->startRepeating(OpenShutter_Key);
+    mainWindow->startRepeating(OpenShutter_Key);
+  }
 }
 
+
 void PIRCameraForm::on_openShutterButton_released()
 {
   mainWindow->stopRepeating();
