@@ -25,11 +25,13 @@
 #include "protocols/panasonicoldprotocol.h"
 #include "protocols/nokia32protocol.h"
 #include "protocols/rc5protocol.h"
+#include <QComboBox>
+
 
 CiscoSTB1::CiscoSTB1(
   unsigned int index)
   : PIRKeysetMetaData(
-      "Set-Top Box Keyset 1",
+      "STB Keyset 1",
       Cisco_Make,
       index)
 {
@@ -97,10 +99,21 @@ void CiscoSTB1::populateProtocol(
 }
 
 
+void CiscoSTB1::populateInputList(
+  QComboBox *cb)
+{
+  cb->clear();
+
+  cb->addItem("TV", QVariant(Input_Key));
+  cb->addItem("HD", QVariant(HDDInput_Key));
+  cb->addItem("Radio", QVariant(TunerInput_Key));
+}
+
+
 CiscoSTB2::CiscoSTB2(
   unsigned int index)
   : PIRKeysetMetaData(
-      "Set-Top Box Keyset 2",
+      "STB Keyset 2",
       Cisco_Make,
       index)
 {
@@ -185,10 +198,21 @@ void CiscoSTB2::populateProtocol(
 }
 
 
+void CiscoSTB2::populateInputList(
+  QComboBox *cb)
+{
+  cb->clear();
+
+  cb->addItem("Video Source", QVariant(Input_Key));
+  cb->addItem("Live", QVariant(LiveTV_Key));
+  cb->addItem("List", QVariant(HDDInput_Key));
+}
+
+
 CiscoSTB3::CiscoSTB3(
   unsigned int index)
   : PIRKeysetMetaData(
-      "Set-Top Box Keyset 3",
+      "STB Keyset 3",
       Cisco_Make,
       index)
 {
@@ -260,7 +284,7 @@ void CiscoSTB3::populateProtocol(
 CiscoSTB4::CiscoSTB4(
   unsigned int index)
   : PIRKeysetMetaData(
-      "Set-Top Box Keyset 4",
+      "STB Keyset 4",
       Cisco_Make,
       index)
 {
