@@ -22,6 +22,7 @@
 
 #include "fortec.h"
 #include "protocols/necprotocol.h"
+#include <QComboBox>
 
 
 FortecReceiver1::FortecReceiver1(
@@ -83,6 +84,16 @@ void FortecReceiver1::populateProtocol(
 }
 
 
+void FortecReceiver1::populateInputList(
+  QComboBox *cb)
+{
+  cb->clear();
+
+  cb->addItem("TV / Radio", QVariant(Input_Key));
+  cb->addItem("Satellite", QVariant(SatInput_Key));
+}
+
+
 FortecReceiver2::FortecReceiver2(
   unsigned int index)
   : PIRKeysetMetaData(
@@ -164,3 +175,12 @@ void FortecReceiver2::populateProtocol(
   addKey("back", Replay_Key, 0x50, 8);
   addKey("fwd", Advance_Key, 0x51, 8);
 }
+
+void FortecReceiver2::populateInputList(
+  QComboBox *cb)
+{
+  cb->clear();
+
+  cb->addItem("TV / DBS", QVariant(Input_Key));
+  cb->addItem("TV / Radio", QVariant(TunerInput_Key));
+}
