@@ -22,6 +22,7 @@
 
 #include "ilo.h"
 #include "protocols/necprotocol.h"
+#include <QComboBox>
 
 ILOTV1::ILOTV1(
   unsigned int index)
@@ -100,6 +101,19 @@ void ILOTV1::populateProtocol(
 }
 
 
+void ILOTV1::populateInputList(
+  QComboBox *cb)
+{
+  cb->clear();
+
+  cb->addItem("TV", QVariant(Input_Key));
+  cb->addItem("AV", QVariant(CompositeInput_Key));
+  cb->addItem("SVideo", QVariant(SVideoInput_Key));
+  cb->addItem("Component", QVariant(ComponentInput_Key));
+  cb->addItem("DVI", QVariant(PCInput_Key));
+}
+
+
 ILOTV2::ILOTV2(
   unsigned int index)
   : PIRKeysetMetaData(
@@ -235,3 +249,13 @@ void ILOTV3::populateProtocol(
   addKey("Menu Left", Left_Key, 0x5E, 8);
   addKey("Menu Right", Right_Key, 0x5F, 8);
 }
+
+
+void ILOTV3::populateInputList(
+  QComboBox *cb)
+{
+  cb->clear();
+
+  cb->addItem("TV", QVariant(Input_Key));
+  cb->addItem("Video", QVariant(AuxInput_Key));
+}
