@@ -23,6 +23,7 @@
 #include "jvc.h"
 #include "protocols/jvcprotocol.h"
 #include "protocols/lircprotocol.h"
+#include <QComboBox>
 
 JVCSat1::JVCSat1(
   unsigned int index)
@@ -732,6 +733,17 @@ void JVCAudio1::populateProtocol(
 }
 
 
+void JVCAudio1::populateInputList(
+  QComboBox *cb)
+{
+  cb->clear();
+
+  cb->addItem("MD / Aux", QVariant(AuxInput_Key));
+  cb->addItem("Tape", QVariant(TapeInput_Key));
+  cb->addItem("Tuner - Band", QVariant(TunerInput_Key));
+}
+
+
 JVCAudio1a::JVCAudio1a(
   unsigned int index)
   : JVCAudio1(index)
@@ -830,6 +842,17 @@ void JVCAudio1b::populateProtocol(
 }
 
 
+void JVCAudio1b::populateInputList(
+  QComboBox *cb)
+{
+  JVCAudio1::populateInputList(cb);
+
+  cb->addItem("VCR", QVariant(VCRInput_Key));
+  cb->addItem("Tuner", QVariant(TunerInput_Key));
+  cb->addItem("Phono", QVariant(PhonoInput_Key));
+}
+
+
 JVCAudio2::JVCAudio2(
   unsigned int index)
   : PIRKeysetMetaData(
@@ -932,6 +955,16 @@ void JVCAudio2::populateProtocol(
 }
 
 
+void JVCAudio2::populateInputList(
+  QComboBox *cb)
+{
+  cb->clear();
+
+  cb->addItem("Tuner Band", QVariant(TunerInput_Key));
+  cb->addItem("Aux", QVariant(AuxInput_Key));
+}
+
+
 JVCDVD1::JVCDVD1(
   unsigned int index)
   : PIRKeysetMetaData(
