@@ -23,6 +23,7 @@
 #include "openbox.h"
 
 #include "protocols/necprotocol.h"
+#include <QComboBox>
 
 OpenBoxSTB1::OpenBoxSTB1(
   unsigned int index)
@@ -105,6 +106,16 @@ void OpenBoxSTB1::populateProtocol(
 }
 
 
+void OpenBoxSTB1::populateInputList(
+  QComboBox *cb)
+{
+  cb->clear();
+
+  cb->addItem("TV / Sat", QVariant(Input_Key));
+  cb->addItem("TV / Radio", QVariant(TunerInput_Key));
+}
+
+
 OpenBoxSTB2::OpenBoxSTB2(
   unsigned int index)
   : PIRKeysetMetaData(
