@@ -23,6 +23,8 @@
 #include "triax.h"
 #include "protocols/rc5protocol.h"
 #include "protocols/necprotocol.h"
+#include <QComboBox>
+
 
 TriaxSTB1::TriaxSTB1(
   unsigned int index)
@@ -139,6 +141,16 @@ void TriaxSTB2::populateProtocol(
 }
 
 
+void TriaxSTB2::populateInputList(
+  QComboBox *cb)
+{
+  cb->clear();
+
+  cb->addItem("Satellite", QVariant(Input_Key));
+  cb->addItem("TV / Radio", QVariant(TunerInput_Key));
+}
+
+
 TriaxSTB2a::TriaxSTB2a(
   unsigned int index)
   : TriaxSTB2(index)
