@@ -34,6 +34,7 @@
 
 class QThread;
 class QObject;
+class QComboBox;
 
 class PIRSelectDeviceForm;
 class PIRProtocol;
@@ -75,6 +76,9 @@ public:
 
   bool clearProtocol();
 
+  virtual void populateInputList(
+    QComboBox *cb);
+
   void moveToThread(
     QThread *thread);
 
