@@ -34,7 +34,9 @@ class PIRMediaForm;
 class PIRMedia2Form;
 class PIRRecordForm;
 class PIRTVForm;
+class PIRReceiverForm;
 class PIRInputForm;
+class PIRInputListForm;
 class PIRAdjustForm;
 class PIRAirConditionerForm;
 class PIRStatefulACForm;
@@ -66,7 +68,7 @@ typedef std::list<PIRPanelName> PIRPanelNameList;
 typedef std::map<PIRTabBarName, PIRPanelNameList> PIRTabsCollection;
 
 typedef std::map<PIRPanelName, QWidget *> PIRPanelCollection;
-typedef std::map<PIRPanelName, const char *> PIRPanelDisplayNameCollection;
+typedef std::map<PIRPanelName, QString> PIRPanelDisplayNameCollection;
 typedef std::map<QString, PIRPanelName> PIRReversePanelIndex;
 
 class PIRPanelManager
@@ -121,7 +123,9 @@ private:
   PIRMedia2Form *media2Form;
   PIRRecordForm *recordForm;
   PIRTVForm *tvForm;
+  PIRReceiverForm *receiverForm;
   PIRInputForm *inputForm;
+  PIRInputListForm *inputListForm;
   PIRAdjustForm *adjustForm;
   PIRAirConditionerForm *acForm;
   PIRStatefulACForm *statefulACForm;
