@@ -34,7 +34,9 @@ enum PIRPanelName
   Media2_Panel,
   Record_Panel,
   TV_Panel,
+  Receiver_Panel,
   Input_Panel,
+  InputList_Panel,
   Adjust_Panel,
   AC_Panel,
   StatefulAC_Panel,
